<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de">
<context>
    <name>AppearancePage</name>
    <message>
        <location filename="../appearancepage.ui" line="20"/>
        <source>Style:</source>
        <translation>Stil:</translation>
    </message>
    <message>
        <location filename="../appearancepage.ui" line="27"/>
        <source>Preview</source>
        <translation>Vorschau</translation>
    </message>
    <message>
        <location filename="../appearancepage.ui" line="34"/>
        <source>Active palette</source>
        <translation>Aktive Palette</translation>
    </message>
    <message>
        <location filename="../appearancepage.ui" line="39"/>
        <source>Inactive palette</source>
        <translation>Inaktive Palette</translation>
    </message>
    <message>
        <location filename="../appearancepage.ui" line="44"/>
        <source>Disabled palette</source>
        <translation>Deaktivierte Palette</translation>
    </message>
    <message>
        <location filename="../appearancepage.ui" line="91"/>
        <source>Palette</source>
        <translation>Palette</translation>
    </message>
    <message>
        <location filename="../appearancepage.ui" line="102"/>
        <source>Default</source>
        <translation>Standard</translation>
    </message>
    <message>
        <location filename="../appearancepage.ui" line="112"/>
        <source>Custom</source>
        <translation>Benutzerdefiniert</translation>
    </message>
    <message>
        <location filename="../appearancepage.ui" line="139"/>
        <source>Color scheme:</source>
        <translation>Farbschema:</translation>
    </message>
    <message>
        <location filename="../appearancepage.ui" line="162"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../appearancepage.cpp" line="65"/>
        <source>Create</source>
        <translation>Erstellen</translation>
    </message>
    <message>
        <location filename="../appearancepage.cpp" line="66"/>
        <source>Edit</source>
        <translation>Bearbeiten</translation>
    </message>
    <message>
        <location filename="../appearancepage.cpp" line="67"/>
        <source>Create a Copy</source>
        <translation>Erstellen Sie eine Kopie</translation>
    </message>
    <message>
        <location filename="../appearancepage.cpp" line="68"/>
        <source>Rename</source>
        <translation>Umbenennen</translation>
    </message>
    <message>
        <location filename="../appearancepage.cpp" line="70"/>
        <source>Remove</source>
        <translation>Entfernen</translation>
    </message>
    <message>
        <location filename="../appearancepage.cpp" line="120"/>
        <location filename="../appearancepage.cpp" line="194"/>
        <location filename="../appearancepage.cpp" line="229"/>
        <source>Enter Color Scheme Name</source>
        <translation>Farbschemaname eingeben</translation>
    </message>
    <message>
        <location filename="../appearancepage.cpp" line="120"/>
        <location filename="../appearancepage.cpp" line="194"/>
        <location filename="../appearancepage.cpp" line="229"/>
        <source>File name:</source>
        <translation>Dateiname:</translation>
    </message>
    <message>
        <location filename="../appearancepage.cpp" line="129"/>
        <location filename="../appearancepage.cpp" line="205"/>
        <location filename="../appearancepage.cpp" line="239"/>
        <source>Error</source>
        <translation>Fehler</translation>
    </message>
    <message>
        <location filename="../appearancepage.cpp" line="129"/>
        <location filename="../appearancepage.cpp" line="205"/>
        <location filename="../appearancepage.cpp" line="239"/>
        <source>The color scheme &quot;%1&quot; already exists</source>
        <translation>Das Farbschema »%1« ist bereits vorhanden</translation>
    </message>
    <message>
        <location filename="../appearancepage.cpp" line="147"/>
        <location filename="../appearancepage.cpp" line="170"/>
        <location filename="../appearancepage.cpp" line="224"/>
        <source>Warning</source>
        <translation>Warnung</translation>
    </message>
    <message>
        <location filename="../appearancepage.cpp" line="147"/>
        <location filename="../appearancepage.cpp" line="170"/>
        <location filename="../appearancepage.cpp" line="224"/>
        <source>The color scheme &quot;%1&quot; is read only</source>
        <translation>Das Farbschema »%1« ist schreibgeschützt</translation>
    </message>
    <message>
        <location filename="../appearancepage.cpp" line="175"/>
        <source>Confirm Remove</source>
        <translation>Entfernen bestätigen</translation>
    </message>
    <message>
        <location filename="../appearancepage.cpp" line="176"/>
        <source>Are you sure you want to remove color scheme &quot;%1&quot;?</source>
        <translation>Sind Sie sicher, dass Sie das Farbschema »%1« entfernen möchten?</translation>
    </message>
    <message>
        <location filename="../appearancepage.cpp" line="196"/>
        <source>%1 (copy)</source>
        <translation>%1 (kopieren)</translation>
    </message>
</context>
<context>
    <name>FontConfigDialog</name>
    <message>
        <location filename="../fontconfigdialog.ui" line="14"/>
        <location filename="../fontconfigdialog.cpp" line="73"/>
        <source>Font Configuration</source>
        <translation>Schriftkonfiguration</translation>
    </message>
    <message>
        <location filename="../fontconfigdialog.ui" line="29"/>
        <source>Disable automatic hinting for bold fonts</source>
        <translation>Automatisches Hinting für Fettschriften deaktivieren</translation>
    </message>
    <message>
        <location filename="../fontconfigdialog.ui" line="36"/>
        <source>LCD filter:</source>
        <translation>LCD-Filter:</translation>
    </message>
    <message>
        <location filename="../fontconfigdialog.ui" line="43"/>
        <source>Automatic hinting</source>
        <translation>Automatisches Hinting</translation>
    </message>
    <message>
        <location filename="../fontconfigdialog.ui" line="50"/>
        <source>Hinting</source>
        <translation>Hinting</translation>
    </message>
    <message>
        <location filename="../fontconfigdialog.ui" line="67"/>
        <source>Font resolution:</source>
        <translation>Schriftauflösung:</translation>
    </message>
    <message>
        <location filename="../fontconfigdialog.ui" line="110"/>
        <source> dpi</source>
        <translation> dpi</translation>
    </message>
    <message>
        <location filename="../fontconfigdialog.ui" line="83"/>
        <source>Subpixel geometry:</source>
        <translation>Teilbildpunkt-Geometrie:</translation>
    </message>
    <message>
        <location filename="../fontconfigdialog.ui" line="90"/>
        <source>Antialiasing</source>
        <translation>Antialiasing (Glättung)</translation>
    </message>
    <message>
        <location filename="../fontconfigdialog.ui" line="97"/>
        <source>Hinting style:</source>
        <translation>Hinting-Stil:</translation>
    </message>
    <message>
        <location filename="../fontconfigdialog.cpp" line="42"/>
        <location filename="../fontconfigdialog.cpp" line="47"/>
        <source>None</source>
        <translation>Keiner</translation>
    </message>
    <message>
        <location filename="../fontconfigdialog.cpp" line="43"/>
        <source>Slight</source>
        <translation>Gering</translation>
    </message>
    <message>
        <location filename="../fontconfigdialog.cpp" line="44"/>
        <source>Medium</source>
        <translation>Mittel</translation>
    </message>
    <message>
        <location filename="../fontconfigdialog.cpp" line="45"/>
        <source>Full</source>
        <translation>Vollständig</translation>
    </message>
    <message>
        <location filename="../fontconfigdialog.cpp" line="74"/>
        <source>&lt;i&gt;%1&lt;/i&gt; already exists. Do you want to replace it?</source>
        <translation>&lt;i&gt;%1&lt;/i&gt; ist bereits vorhanden. Wollen Sie es ersetzen?</translation>
    </message>
</context>
<context>
    <name>FontsPage</name>
    <message>
        <location filename="../fontspage.ui" line="44"/>
        <location filename="../fontspage.ui" line="64"/>
        <location filename="../fontspage.ui" line="80"/>
        <location filename="../fontspage.ui" line="87"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../fontspage.ui" line="57"/>
        <source>General:</source>
        <translation>Allgemein:</translation>
    </message>
    <message>
        <location filename="../fontspage.ui" line="94"/>
        <source>Fixed width:</source>
        <translation>Feste Breite:</translation>
    </message>
    <message>
        <location filename="../fontspage.ui" line="119"/>
        <source>Create  fonts.conf</source>
        <translation>fonts.conf erstellen</translation>
    </message>
    <message>
        <location filename="../fontspage.ui" line="126"/>
        <source>Remove fonts.conf</source>
        <translation>fonts.conf löschen</translation>
    </message>
    <message>
        <location filename="../fontspage.cpp" line="115"/>
        <source>Remove Font Configuration</source>
        <translation>Schriftkonfiguration entfernen</translation>
    </message>
    <message>
        <location filename="../fontspage.cpp" line="116"/>
        <source>Are you sure you want to delete &lt;i&gt;%1&lt;/i&gt;?</source>
        <translation>Sind Sie sicher, dass Sie &lt;i&gt;%1&lt;/i&gt; löschen wollen?</translation>
    </message>
</context>
<context>
    <name>InterfacePage</name>
    <message>
        <location filename="../interfacepage.ui" line="35"/>
        <source>Double click interval:</source>
        <translation>Doppelklickintervall:</translation>
    </message>
    <message>
        <location filename="../interfacepage.ui" line="42"/>
        <source>Cursor flash time:</source>
        <translation>Eingabezeiger-Blinkdauer:</translation>
    </message>
    <message>
        <location filename="../interfacepage.ui" line="49"/>
        <source>ComboBox effect:</source>
        <translation>ComboBox-Effekt:</translation>
    </message>
    <message>
        <location filename="../interfacepage.ui" line="56"/>
        <source>ToolTip effect:</source>
        <translation>Kurzinfo-Effekt:</translation>
    </message>
    <message>
        <location filename="../interfacepage.ui" line="63"/>
        <source>ToolBox effect:</source>
        <translation>Werkzeugkasten-Effekt:</translation>
    </message>
    <message>
        <location filename="../interfacepage.ui" line="70"/>
        <location filename="../interfacepage.ui" line="80"/>
        <source> ms</source>
        <translation> ms</translation>
    </message>
    <message>
        <location filename="../interfacepage.ui" line="94"/>
        <location filename="../interfacepage.ui" line="111"/>
        <location filename="../interfacepage.ui" line="133"/>
        <location filename="../interfacepage.ui" line="157"/>
        <source>Disable</source>
        <translation>Deaktivieren</translation>
    </message>
    <message>
        <location filename="../interfacepage.ui" line="99"/>
        <location filename="../interfacepage.ui" line="116"/>
        <location filename="../interfacepage.ui" line="138"/>
        <location filename="../interfacepage.ui" line="162"/>
        <source>Animate</source>
        <translation>Animieren</translation>
    </message>
    <message>
        <location filename="../interfacepage.ui" line="121"/>
        <location filename="../interfacepage.ui" line="167"/>
        <source>Fade</source>
        <translation>Ausblenden</translation>
    </message>
    <message>
        <location filename="../interfacepage.ui" line="146"/>
        <source>Menu effect:</source>
        <translation>Menü-Effekt:</translation>
    </message>
    <message>
        <location filename="../interfacepage.ui" line="175"/>
        <source>Enable gui effects</source>
        <translation>Grafische Effekte aktivieren</translation>
    </message>
    <message>
        <location filename="../interfacepage.ui" line="182"/>
        <source>Dialog buttons layout:</source>
        <translation>Anordnung der Dialogschaltflächen:</translation>
    </message>
    <message>
        <location filename="../interfacepage.ui" line="192"/>
        <source>Menus have icons</source>
        <translation>Menüs haben Symbole</translation>
    </message>
    <message>
        <location filename="../interfacepage.ui" line="199"/>
        <source>Dialog buttons have icons</source>
        <translation>Dialogschaltflächen haben Symbole</translation>
    </message>
    <message>
        <location filename="../interfacepage.ui" line="209"/>
        <source>Activate item on single-click</source>
        <translation>Eintrag mit einem Einfachklick aktivieren</translation>
    </message>
    <message>
        <location filename="../interfacepage.ui" line="219"/>
        <source>Toolbar button style:</source>
        <translation>Werkzeugleiste-Schaltflächenstil:</translation>
    </message>
    <message>
        <location filename="../interfacepage.ui" line="229"/>
        <source>Mouse wheel scroll lines:</source>
        <translation>Mausrad-Bildlaufzeilen:</translation>
    </message>
    <message>
        <location filename="../interfacepage.cpp" line="47"/>
        <source>Only display the icon</source>
        <translation>Nur das Symbol anzeigen</translation>
    </message>
    <message>
        <location filename="../interfacepage.cpp" line="48"/>
        <source>Only display the text</source>
        <translation>Nur den Text anzeigen</translation>
    </message>
    <message>
        <location filename="../interfacepage.cpp" line="49"/>
        <source>The text appears beside the icon</source>
        <translation>Der Text erscheint neben dem Symbol</translation>
    </message>
    <message>
        <location filename="../interfacepage.cpp" line="50"/>
        <source>The text appears under the icon</source>
        <translation>Der Text erscheint unter dem Symbol</translation>
    </message>
    <message>
        <location filename="../interfacepage.cpp" line="51"/>
        <source>Follow the application style</source>
        <translation>Dem Anwendungsstil folgen</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <source>Qt5 Configuration Tool</source>
        <translation>Qt5-Konfigurationswerkzeug</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="45"/>
        <source>Appearance</source>
        <translation>Erscheinungsbild</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="46"/>
        <source>Fonts</source>
        <translation>Schriftarten</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="47"/>
        <source>Icon Theme</source>
        <translation>Symbolthema</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="48"/>
        <source>Interface</source>
        <translation>Oberfläche</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="50"/>
        <source>Style Sheets</source>
        <translation>Stilvorlagen</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="58"/>
        <source>Version: %1</source>
        <translation>Version: %1</translation>
    </message>
</context>
<context>
    <name>PaletteEditDialog</name>
    <message>
        <location filename="../paletteeditdialog.ui" line="14"/>
        <source>Palette Editor</source>
        <translation>Paletteneditor</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.ui" line="79"/>
        <source>Reset palette</source>
        <translation>Palette zurücksetzen</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.ui" line="29"/>
        <source>Build inactive palette</source>
        <translation>Inaktive Palette erstellen</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.ui" line="36"/>
        <source>Build disabled palette</source>
        <translation>Deaktivierte Palette erstellen</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="49"/>
        <source>Active</source>
        <translation>Aktiv</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="49"/>
        <source>Inactive</source>
        <translation>Inaktiv</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="49"/>
        <source>Disabled</source>
        <translation>Deaktiviert</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="91"/>
        <source>Dark</source>
        <translation>Dunkel</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="91"/>
        <source>Window text</source>
        <translation>Fenstertext</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="91"/>
        <source>Button background</source>
        <translation>Knopfhintergrund</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="91"/>
        <source>Bright</source>
        <translation>Hell</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="91"/>
        <source>Less bright</source>
        <translation>Weniger hell</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="91"/>
        <source>Less dark</source>
        <translation>Weniger dunkel</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="92"/>
        <source>Window</source>
        <translation>Fenster</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="92"/>
        <source>Shadow</source>
        <translation>Schatten</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="92"/>
        <source>Bright text</source>
        <translation>Heller Text</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="92"/>
        <source>Button text</source>
        <translation>Schaltflächentext</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="92"/>
        <source>Normal text</source>
        <translation>Normaler Text</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="92"/>
        <source>Normal background</source>
        <translation>Normaler Hintergrund</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="93"/>
        <source>Highlight</source>
        <translation>Hervorheben</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="93"/>
        <source>Highlighted text</source>
        <translation>Hervorgehobener Text</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="93"/>
        <source>Visited link</source>
        <translation>Besuchter Link</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="94"/>
        <source>Default</source>
        <translation>Standard</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="94"/>
        <source>Tooltip background</source>
        <translation>Kurzinfo-Hintergrund</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="94"/>
        <source>Tooltip text</source>
        <translation>Kurzinfo-Text</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="93"/>
        <source>Link</source>
        <translation>Link</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="94"/>
        <source>Alternate background</source>
        <translation>Alternativer Hintergrund</translation>
    </message>
    <message>
        <location filename="../paletteeditdialog.cpp" line="106"/>
        <source>Select Color</source>
        <translation>Farbe auswählen</translation>
    </message>
</context>
<context>
    <name>PreviewForm</name>
    <message>
        <location filename="../previewform.ui" line="14"/>
        <source>Preview Window</source>
        <translation>Vorschaufenster</translation>
    </message>
    <message>
        <location filename="../previewform.ui" line="24"/>
        <source>Tab 1</source>
        <translation>Reiter 1</translation>
    </message>
    <message>
        <location filename="../previewform.ui" line="30"/>
        <source>PushButton</source>
        <translation>Schaltfläche drücken</translation>
    </message>
    <message>
        <location filename="../previewform.ui" line="51"/>
        <source>Tab 2</source>
        <translation>Reiter 2</translation>
    </message>
    <message>
        <location filename="../previewform.ui" line="57"/>
        <source>RadioButton</source>
        <translation>Radioschaltfläche</translation>
    </message>
    <message>
        <location filename="../previewform.ui" line="64"/>
        <source>CheckBox</source>
        <translation>Ankreuzfeld</translation>
    </message>
</context>
<context>
    <name>QSSEditorDialog</name>
    <message>
        <location filename="../qsseditordialog.cpp" line="45"/>
        <source>%1 - Style Sheet Editor</source>
        <translation>%1 - Stilvorlagen-Editor</translation>
    </message>
    <message>
        <location filename="../qsseditordialog.ui" line="14"/>
        <source>Style Sheet Editor</source>
        <translation>Stilvorlagen-Editor</translation>
    </message>
</context>
<context>
    <name>QSSPage</name>
    <message>
        <location filename="../qsspage.ui" line="23"/>
        <source>Create</source>
        <translation>Erstellen</translation>
    </message>
    <message>
        <location filename="../qsspage.ui" line="66"/>
        <location filename="../qsspage.cpp" line="51"/>
        <source>Edit</source>
        <translation>Bearbeiten</translation>
    </message>
    <message>
        <location filename="../qsspage.ui" line="76"/>
        <location filename="../qsspage.cpp" line="52"/>
        <source>Rename</source>
        <translation>Umbenennen</translation>
    </message>
    <message>
        <location filename="../qsspage.ui" line="33"/>
        <location filename="../qsspage.cpp" line="54"/>
        <source>Remove</source>
        <translation>Entfernen</translation>
    </message>
    <message>
        <location filename="../qsspage.cpp" line="102"/>
        <source>File name:</source>
        <translation>Dateiname:</translation>
    </message>
    <message>
        <location filename="../qsspage.cpp" line="102"/>
        <source>Enter Style Sheet Name</source>
        <translation>Stilvorlagenname eingeben</translation>
    </message>
    <message>
        <location filename="../qsspage.cpp" line="113"/>
        <location filename="../qsspage.cpp" line="205"/>
        <location filename="../qsspage.cpp" line="216"/>
        <source>Error</source>
        <translation>Fehler</translation>
    </message>
    <message>
        <location filename="../qsspage.cpp" line="113"/>
        <source>The file &quot;%1&quot; already exists</source>
        <translation>Die Datei &quot;%1&quot; ist bereits vorhanden</translation>
    </message>
    <message>
        <location filename="../qsspage.cpp" line="147"/>
        <source>Confirm Remove</source>
        <translation>Entfernen bestätigen</translation>
    </message>
    <message>
        <location filename="../qsspage.cpp" line="148"/>
        <source>Are you sure you want to remove style sheet &quot;%1&quot;?</source>
        <translation>Sind Sie sicher, dass Sie die Stilvorlage »%1« entfernen möchten?</translation>
    </message>
    <message>
        <location filename="../qsspage.cpp" line="198"/>
        <source>Rename Style Sheet</source>
        <translation>Stilvorlage umbenennen</translation>
    </message>
    <message>
        <location filename="../qsspage.cpp" line="198"/>
        <source>Style sheet name:</source>
        <translation>Stilvorlagenname:</translation>
    </message>
    <message>
        <location filename="../qsspage.cpp" line="205"/>
        <source>The style sheet &quot;%1&quot; already exists</source>
        <translation>Die Stilvorlage »%1« ist bereits vorhanden</translation>
    </message>
    <message>
        <location filename="../qsspage.cpp" line="216"/>
        <source>Unable to rename file</source>
        <translation>Datei konnte nicht umbenannt werden</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../main.cpp" line="60"/>
        <source>Please remove the &lt;b&gt;QT_STYLE_OVERRIDE&lt;/b&gt; environment variable</source>
        <translation>Bitte entfernen Sie die Umgebungsvariable &lt;b&gt;QT_STYLE_OVERRIDE&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="65"/>
        <source>The &lt;b&gt;QT_QPA_PLATFORMTHEME&lt;/b&gt; environment variable is not set correctly</source>
        <translation>Die Umgebungsvariable &lt;b&gt;QT_QPA_PLATFORMTHEME&lt;/b&gt; ist nicht korrekt festgelegt</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="71"/>
        <source>Unable to find &lt;b&gt;libqt5ct-style.so&lt;/b&gt;</source>
        <translation>&lt;b&gt;libqt5ct-style.so&lt;/b&gt; kann nicht gefunden werden</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="76"/>
        <source>Error</source>
        <translation>Fehler</translation>
    </message>
</context>
</TS>
